@@ -4,12 +4,13 @@ from .double_ml_plr import DoubleMLPLR
 from .double_ml_pliv import DoubleMLPLIV
 from .double_ml_irm import DoubleMLIRM
 from .double_ml_iivm import DoubleMLIIVM
-from .double_ml_data import DoubleMLData
+from .double_ml_data import DoubleMLData, DoubleMLClusterData
 
 __all__ = ['DoubleMLPLR',
            'DoubleMLPLIV',
            'DoubleMLIRM',
            'DoubleMLIIVM',
-           'DoubleMLData']
+           'DoubleMLData',
+           'DoubleMLClusterData']
 
 __version__ = get_distribution('doubleml').version
