@@ -8,9 +8,9 @@ from sklearn.linear_model import Lasso
 
 np.random.seed(3141)
 dml_data = make_plr_CCDDHNR2018(n_obs=10)
-ml_g = Lasso()
+ml_l = Lasso()
 ml_m = Lasso()
-dml_plr = DoubleMLPLR(dml_data, ml_g, ml_m,
+dml_plr = DoubleMLPLR(dml_data, ml_l, ml_m,
                       n_folds=7, n_rep=8,
                       draw_sample_splitting=False)
 
@@ -172,9 +172,9 @@ def test_doubleml_set_sample_splitting_all_list():
 @pytest.mark.ci
 def test_doubleml_draw_vs_set():
     np.random.seed(3141)
-    dml_plr_set = DoubleMLPLR(dml_data, ml_g, ml_m, n_folds=7, n_rep=8)
+    dml_plr_set = DoubleMLPLR(dml_data, ml_l, ml_m, n_folds=7, n_rep=8)
 
-    dml_plr_drawn = DoubleMLPLR(dml_data, ml_g, ml_m,
+    dml_plr_drawn = DoubleMLPLR(dml_data, ml_l, ml_m,
                                 n_folds=1, n_rep=1, apply_cross_fitting=False)
     dml_plr_set.set_sample_splitting(dml_plr_drawn.smpls)
     _assert_resampling_pars(dml_plr_drawn, dml_plr_set)
@@ -183,7 +183,7 @@ def test_doubleml_draw_vs_set():
     dml_plr_set.set_sample_splitting(dml_plr_drawn.smpls[0][0])
     _assert_resampling_pars(dml_plr_drawn, dml_plr_set)
 
-    dml_plr_drawn = DoubleMLPLR(dml_data, ml_g, ml_m,
+    dml_plr_drawn = DoubleMLPLR(dml_data, ml_l, ml_m,
                                 n_folds=2, n_rep=1, apply_cross_fitting=False)
     dml_plr_set.set_sample_splitting(dml_plr_drawn.smpls)
     _assert_resampling_pars(dml_plr_drawn, dml_plr_set)
@@ -192,26 +192,26 @@ def test_doubleml_draw_vs_set():
     dml_plr_set.set_sample_splitting(dml_plr_drawn.smpls[0][0])
     _assert_resampling_pars(dml_plr_drawn, dml_plr_set)
 
-    dml_plr_drawn = DoubleMLPLR(dml_data, ml_g, ml_m,
+    dml_plr_drawn = DoubleMLPLR(dml_data, ml_l, ml_m,
                                 n_folds=2, n_rep=1, apply_cross_fitting=True)
     dml_plr_set.set_sample_splitting(dml_plr_drawn.smpls)
     _assert_resampling_pars(dml_plr_drawn, dml_plr_set)
     dml_plr_set.set_sample_splitting(dml_plr_drawn.smpls[0])
     _assert_resampling_pars(dml_plr_drawn, dml_plr_set)
 
-    dml_plr_drawn = DoubleMLPLR(dml_data, ml_g, ml_m,
+    dml_plr_drawn = DoubleMLPLR(dml_data, ml_l, ml_m,
                                 n_folds=5, n_rep=1, apply_cross_fitting=True)
     dml_plr_set.set_sample_splitting(dml_plr_drawn.smpls)
     _assert_resampling_pars(dml_plr_drawn, dml_plr_set)
     dml_plr_set.set_sample_splitting(dml_plr_drawn.smpls[0])
     _assert_resampling_pars(dml_plr_drawn, dml_plr_set)
 
-    dml_plr_drawn = DoubleMLPLR(dml_data, ml_g, ml_m,
+    dml_plr_drawn = DoubleMLPLR(dml_data, ml_l, ml_m,
                                 n_folds=5, n_rep=3, apply_cross_fitting=True)
     dml_plr_set.set_sample_splitting(dml_plr_drawn.smpls)
     _assert_resampling_pars(dml_plr_drawn, dml_plr_set)
 
-    dml_plr_drawn = DoubleMLPLR(dml_data, ml_g, ml_m,
+    dml_plr_drawn = DoubleMLPLR(dml_data, ml_l, ml_m,
                                 n_folds=2, n_rep=4, apply_cross_fitting=False)
     dml_plr_set.set_sample_splitting(dml_plr_drawn.smpls)
     _assert_resampling_pars(dml_plr_drawn, dml_plr_set)
