@@ -13,7 +13,7 @@ if (on_cran) {
     stringsAsFactors = FALSE)
 } else {
   test_cases = expand.grid(
-    learner = c("regr.lm", "regr.cv_glmnet"),
+    learner = c("regr.lm", "regr.cv_glmnet", "graph_learner"),
     dml_procedure = c("dml1", "dml2"),
     score = c("IV-type", "partialling out"),
     stringsAsFactors = FALSE)
@@ -30,7 +30,9 @@ patrick::with_parameters_test_that("Unit tests for PLR:",
     plr_hat = dml_plr(data_plr$df,
       y = "y", d = "d",
       n_folds = n_folds,
-      ml_g = learner_pars$ml_g$clone(), ml_m = learner_pars$ml_m$clone(),
+      ml_l = learner_pars$ml_l$clone(),
+      ml_m = learner_pars$ml_m$clone(),
+      ml_g = learner_pars$ml_g$clone(),
       dml_procedure = dml_procedure, score = score)
     theta = plr_hat$coef
     se = plr_hat$se
@@ -47,13 +49,24 @@ patrick::with_parameters_test_that("Unit tests for PLR:",
       score = score)$boot_coef
 
     set.seed(3141)
-    double_mlplr_obj = DoubleMLPLR$new(
-      data = data_plr$dml_data,
-      ml_g = learner_pars$ml_g$clone(),
-      ml_m = learner_pars$ml_m$clone(),
-      dml_procedure = dml_procedure,
-      n_folds = n_folds,
-      score = score)
+    if (score == "partialling out") {
+      double_mlplr_obj = DoubleMLPLR$new(
+        data = data_plr$dml_data,
+        ml_l = learner_pars$ml_g$clone(),
+        ml_m = learner_pars$ml_m$clone(),
+        dml_procedure = dml_procedure,
+        n_folds = n_folds,
+        score = score)
+    } else {
+      double_mlplr_obj = DoubleMLPLR$new(
+        data = data_plr$dml_data,
+        ml_l = learner_pars$ml_l$clone(),
+        ml_m = learner_pars$ml_m$clone(),
+        ml_g = learner_pars$ml_g$clone(),
+        dml_procedure = dml_procedure,
+        n_folds = n_folds,
+        score = score)
+    }
 
     double_mlplr_obj$fit()
     theta_obj = double_mlplr_obj$coef
